Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(289)

Unified Diff: chrome/browser/net/net_log_temp_file.h

Issue 1079163007: net_log_logger_ replaced with write_to_file_observer_ (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: net_log_logger_ replaced with write_to_file_observer_ Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/net/chrome_net_log.cc ('k') | chrome/browser/net/net_log_temp_file.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/net/net_log_temp_file.h
diff --git a/chrome/browser/net/net_log_temp_file.h b/chrome/browser/net/net_log_temp_file.h
index 2b96276449587ababa206f0be90018a979b11c30..0ea28ab066a6ee4801aff207f0580b7382dc03eb 100644
--- a/chrome/browser/net/net_log_temp_file.h
+++ b/chrome/browser/net/net_log_temp_file.h
@@ -151,9 +151,9 @@ class NetLogTempFile {
base::FilePath log_path_; // base::FilePath to the temporary file.
- // |net_log_logger_| watches the NetLog event stream, and sends all entries to
- // the file created in StartNetLog().
- scoped_ptr<net::WriteToFileNetLogObserver> net_log_logger_;
+ // |write_to_file_observer_| watches the NetLog event stream, and
+ // sends all entries to the file created in StartNetLog().
+ scoped_ptr<net::WriteToFileNetLogObserver> write_to_file_observer_;
// The |chrome_net_log_| is owned by the browser process, cached here to avoid
// using global (g_browser_process).
« no previous file with comments | « chrome/browser/net/chrome_net_log.cc ('k') | chrome/browser/net/net_log_temp_file.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698